=======
History
=======

0.1.8 (2011-06-21)
------------------
* Fix the request bug that returns just a month from time.ir
* Fix the bug for duplicate holiday dates (ex: 13th Farvardin)
* Use jdatetime as date convertor which is more updated

0.1.0 (2018-06-06)
------------------

* First release on PyPI.
